@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django import template
 
 from ..models import Answer
@@ -10,6 +8,6 @@ register = template.Library()
 @register.filter
 def answer(answer_id):
     try:
-        return answer_id and Answer.objects.get(id=answer_id)
+        return answer_id and Answer.objects.get(id=answer_id.value)
     except Answer.DoesNotExist:
         return None
